@@ -6,7 +6,7 @@ import os
 import flask
 import octoprint.plugin
 import octoprint.util
-from typing import Any, Dict
+from typing import Any, Dict, List
 
 from octoprint.events import Events
 
@@ -16,13 +16,14 @@ from octoprint.logging.handlers import CleaningTimedRotatingFileHandler
 from octoprint_nanny.events import try_handle_event
 from octoprint_nanny.manager import WorkerManager
 from octoprint_nanny.utils.printnanny_os import (
+    issue_txt,
     printnanny_device,
-    printnanny_version,
     printnanny_config,
     printnanny_user,
     printnanny_device,
     janus_edge_hostname,
     janus_edge_api_token,
+    etc_os_release,
 )
 
 logger = logging.getLogger("octoprint.plugins.octoprint_nanny")
@@ -157,18 +158,16 @@ class OctoPrintNannyPlugin(
             logger.error("Plugin manager failed to get backup helper")
             raise Exception("Plugin manager failed to get backup helper")
 
-    def register_custom_events(self):
+    def register_custom_events(self) -> List[str]:
         remote_commands = [
             "remote_command_received",
             "remote_command_failed",
             "remote_command_success",
             "connect_test_mqtt_pong_success",
+            "nnstreamer_start",
+            "nnstreamer_stop",
         ]
-        local_only = [
-            "monitoring_frame_b64",  # not sent via event telemetry
-            "monitoring_frame_bytes",
-        ]
-        return remote_commands + local_only
+        return remote_commands
 
     def on_shutdown(self):
         logger.info("Running on_shutdown handler")
@@ -226,13 +225,6 @@ class OctoPrintNannyPlugin(
 
     def get_template_vars(self):
         custom = {
-            "config": printnanny_config(),
-            # @ todo is there a covenience method to get all plugin settings?
-            # https://docs.octoprint.org/en/master/modules/plugin.html?highlight=settings%20get#octoprint.plugin.PluginSettings.get
-            "settings": {
-                key: self._settings.get([key])
-                for key in self.get_settings_defaults().keys()
-            },
             "urls": {
                 "getting_started_guide": "https://bitsy-ai.notion.site/Getting-Started-with-Print-Nanny-OS-817bc65297ff44a085120c663dced5f3",
                 "discord_invite": "https://discord.gg/sf23bk2hPr",
@@ -242,11 +234,10 @@ class OctoPrintNannyPlugin(
             "printnanny_device": printnanny_device(),
             "janus_edge_hostname": janus_edge_hostname(),
             "janus_edge_api_token": janus_edge_api_token(),
+            "issue_txt": issue_txt(),
+            "etc_os_release": etc_os_release(),
+            "config": printnanny_config(),
         }
-        version_info = printnanny_version()
-        if version_info is not None:
-            custom.update(version_info)
-        logger.info("get_template_vars=%s", custom)
         return custom
 
     ## Wizard plugin mixin
